##  Limitations
  * You can only access content from reports, diagrams, or fact sheets in Confluence if you have an SAP LeanIX account.
  * The SAP LeanIX for Confluence integration does not support page exports in Confluence. This means that embedded reports, diagrams, or fact sheets are not included in exported Confluence pages.
  * Smart Links work only on Confluence pages. They do not function in Live Docs. You can add a LeanIX fact sheet to a Confluence Live Doc, but it will not create a Smart Link in the fact sheets resource tab.
  * For Data Center and Server Editions of the SAP LeanIX for Confluence app, Smart Links only appear after you run a scheduled job (cron job).
